@@ -405,8 +405,8 @@ sub basic_dirs {
 		my ( $ref_DIR_FUNCTION, $ref_DIR ) =
 		  $read->configs( ( $prog_name . '.config' ) );
 		$Project->{_ref_DIR} = $ref_DIR;
-		print(
-			" 3. Project_config,basic_dirs,ref_DIR:@{$Project->{_ref_DIR}}\n");
+#		print(
+#			" 3. Project_config,basic_dirs,ref_DIR:@{$Project->{_ref_DIR}}\n");
 		$Project->{_ref_DIR_FUNCTION} = $ref_DIR_FUNCTION;
 		_change_basic_dirs();
 
